import keyboard
import os

def clear():
    os.system('cls' if os.name == 'nt' else 'clear')

class Menu:
    def __init__(self, title:str, items:list, color="\033[1;32;40m", symbol:str=">", pre_selected:int=0):
        self.selected = pre_selected
        self.title = title
        self.items = items
        self.symbol = symbol
        self.color = color

    def prepare(self):
        clear()
        print(self.title)
        for i in range(0, len(self.items)):
            print("{1} {0}. {2}".format(i + 1, "{1}{0}".format(self.symbol, self.color) if self.selected == i else " ", self.items[i] + "\x1b[0m"))

    def up(self):
        if self.selected == 0:
            return
        self.selected -= 1
        self.prepare()

    def down(self):
        if self.selected == len(self.items) - 1:
            return
        self.selected += 1
        self.prepare()

    def show_menu(self):
        self.prepare()
        keyboard.add_hotkey('up', self.up)
        keyboard.add_hotkey('down', self.down)
        keyboard.wait("enter")
        input()
        return self.selected


from setuptools import setup, find_packages
from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

classifiers = [
  'Development Status :: 5 - Production/Stable',
  'Intended Audience :: Education',
  'Operating System :: Microsoft :: Windows :: Windows 10',
  'License :: OSI Approved :: MIT License',
  'Programming Language :: Python :: 3'
]
 
setup(
  name='kiwi_menu',
  version='1.0.2',
  description='A simple terminal menu for python',
  long_description_content_type='text/markdown',
  long_description=long_description,
  url='',  
  author='mi66mc',
  author_email='miguelmalgarezi@gmail.com',
  license='MIT', 
  classifiers=classifiers,
  keywords='menu', 
  packages=find_packages(),
  install_requires=['keyboard'] 
)